#ifndef NT2_INCLUDE_FUNCTIONS_ISCOLUMN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISCOLUMN_HPP_INCLUDED

#include <nt2/predicates/include/functions/iscolumn.hpp>

#endif
